summaryrefslogtreecommitdiffstats
path: root/db/gorm_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'db/gorm_test.go')
-rw-r--r--db/gorm_test.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/db/gorm_test.go b/db/gorm_test.go
index ec61824..ec3e2a7 100644
--- a/db/gorm_test.go
+++ b/db/gorm_test.go
@@ -5,7 +5,7 @@ import (
"testing"
"github.com/azhao12345/gorm"
- "github.com/ewhal/nyaa/config"
+ "github.com/NyaaPantsu/nyaa/config"
)
type errorLogger struct {
@@ -54,7 +54,7 @@ func TestGormInitSqlite(t *testing.T) {
// - psql -c "CREATE USER nyaapantsu WITH PASSWORD 'nyaapantsu';" -U postgres
//
// Then enable the test by setting this variable to "true" via ldflags:
// go test ./... -v -ldflags="-X github.com/ewhal/nyaa/db.testPostgres=true"
var testPostgres = "false"
func TestGormInitPostgres(t *testing.T) {
@@ -54,7 +54,7 @@ func TestGormInitSqlite(t *testing.T) {
//
// Then enable the test by setting this variable to "true" via ldflags:
-// go test ./... -v -ldflags="-X github.com/ewhal/nyaa/db.testPostgres=true"
+// go test ./... -v -ldflags="-X github.com/NyaaPantsu/nyaa/db.testPostgres=true"
var testPostgres = "false"
func TestGormInitPostgres(t *testing.T) {